cmoncrawl.integrations.download
===============================

.. automodule:: cmoncrawl.integrations.download

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_args
      add_mode_args
      get_aggregator
      get_download_downloader
      run_download
      url_download
      url_download_prepare_router
      url_download_prepare_streamer
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Aggregator
      DownloadOutputFormat
   
   

   
   
   



